Kik iPhone
==========

[![Build Status](https://magnum.travis-ci.com/kikinteractive/kik-iphone.svg?token=4dFpnBywgd3mXcxi9qzH&branch=dev)](https://magnum.travis-ci.com/kikinteractive/kik-iphone)

Contributing
---------------------------

Contributions are highly encouraged! Any way to make the product better is considered.

If you wish to make a product change, please follow the [Product Change Workflow](https://trello.com/c/CQiMXY7W/169-how-do-i-get-a-product-change-into-the-messenger). This workflow explains the requirements that must be met in order for your change to ship.

For the technical side, all developers must follow the [Code Change Workflow](https://trello.com/c/sxkhANzI/27-how-do-i-submit-mobile-code). Basically, your code must be code reviewed, tested, and meet the standards of the existing codebase. This workflow is used for all code changes (features and bug fixes).

Developing
----------

Developing for the Kik iPhone project requires little-to-no manual setup, aside from installing Xcode. 

**Note**: Always open `kik.xcworkspace` in order to be able to build using cocoapods. 

#### Requirements

- Xcode. Just download from the App Store and you'll be set.
- Cocoapods. Run `sudo gem install cocoapods` in terminal to install cocoapods.
- Access to the [kik-localization](https://github.com/kikinteractive/kik-localization) repository. This is needed to pull in the localization files, which happens automatically as a build phase. You should already have access, so just try building and see what happens.

#### Building

- There are two main options for building Kik: `Production` or `Enterprise`. `Production` builds against the default `com.kik.chat` identifier and is the build that is submitted to Apple. `Enterprise` uses `com.kik.chat.enterprise` and is only distributed internally.
- Both options can be built through pre-defined Schemes (see the Xcode section below).

#### Running

- Deploying to the simulator should work out of the box using either scheme (`Kik Production` or `Kik Enterprise`).
- Deploying to a device requires a Development Certification Key and adding the Apple Developer account to Xcode. For the time being, you'll need to bug Kyle.

#### Adding dependencies via Cocoapods

- Add the desired pod name + version in the `Podfile`. (ie `pod 'KikAPI', '1.1.0'`). It is peferred that you set the version number to ensure everyone is using the same version of the pod.
- Save the podfile.
- Run `pod install`.

#### Branching

- Follow the [Git Workflow](https://github.com/kikinteractive/kik-mobile/wiki/Git-Workflow) guidelines which detail how you should branch off `dev`. Typically, most work will fall under the `feature` or `fixer` category.

#### Pushing Changes to GitHub

- In order to push your changes, you'll need to be a member of the [Kik Mobile Developers Push](https://github.com/orgs/kikinteractive/teams/kik-mobile-developers-push) team or already have access through another team. If you need to be added to the Push team, let Kyle know.

Xcode
-----

#### Configurations

Configurations provide the ability to compile builds with pre-defined attributes. Many of these attributes are defined in the configuration files.

<table>
<th>Configuration</th><th>File</th><th>App</th>
<tr><td>Debug-Production</td><td>kik.debug.production</td><td>com.kik.chat</td></tr>
<tr><td>Debug-Enterprise</td><td>kik.debug.enterprise</td><td>com.kik.chat.enterprise</td></tr>
<tr><td>Release-Production</td><td>kik.release.production</td><td>com.kik.chat</td></tr>
<tr><td>Release-Enterprise</td><td>kik.release.enterprise</td><td>com.kik.chat.enterprise</td></tr>
<tr><td>Distribution-Production</td><td>kik.distribution.production</td><td>com.kik.chat</td></tr>
</table>

#### Schemes

Xcode schemes provide an easy way to build Kik from within Xcode. Schemes map to specific configurations (defined above).

<table>
<th>Scheme</th><th>Configuration</th>
<tr><td>Kik Production</td><td>Debug-Production</td></tr>
<tr><td>Kik Enterprise</td><td>Debug-Enterprise</td></tr>
<tr><td>KikTests Production</td><td>Debug-Production</td></tr>
</table>

**Note**: Essentially, if you want to build for Enterprise from Xcode, select `Kik Enterprise`. Otherwise, select `Kik Production`.


Building
------

#### Monitoring

Visit the [Mobile builds](https://mobile.kik.com/builds) page to see progress on `master`, `dev`, and `feature` builds. If you don't see your branch building, make sure you followed the branching guidelines mentioned above. Also remember that `fixer` branches are not built.

#### Installing

Once your build completes, visit Shippy ([https://shippy2.herokuapp.com](https://shippy2.herokuapp.com)) to install your build. For `Production` builds, you'll need a provisioned iPhone, iPod, or iPad. If your device is not provisioned, ask for a test device from QA. For `Enterprise`, any device will do.

Debugging
---------

#### Reveal

To help with view debugging, the Reveal framework is included in the Kik Xcode project. To enable Reveal, add two entries to `Debug-Production` in the `Other Linker Flags` section of the Xcode project settings: `-framework` and `Reveal`

Documentation
-------------

Many features are well documented on the [kik-product wiki](https://github.com/kikinteractive/kik-product/wiki), along with specifications for the XMPP layer, card plugins, and server APIs.

The [kik-mobile wiki](https://github.com/kikinteractive/kik-mobile/wiki) contains information about Mobile-specific processes, like the [Objective-C coding guidelines](https://github.com/kikinteractive/kik-iphone/wiki/Objective-C-Coding-Guidelines) and the [Travis build server](https://github.com/kikinteractive/kik-mobile/wiki/Travis).

Support
-------

If you're lost, be sure to check out: 
- [Messenger Roadmap](https://trello.com/b/NR3UIXuv/messenger-roadmap) a high level description of upcoming releases and workflows
- [Mobile Core](https://trello.com/b/qoA9jMwg/mobile-core) the technical details about how to submit code

If you want to learn more about cocoapods, check out [this link](https://guides.cocoapods.org/using/using-cocoapods.html).

Regarding bugs, please submit new issues on the [kik-iphone Issues Page](https://www.github.com/kikinteractive/kik-iphone/issues). These bugs are triaged by the Messenger team and assigned to the appropriate squad.

If you have any other questions or concerns, please contact Christine or Kyle.
 
